EXPORTS
	??0CUniImageProcessor@@QAE@PAVMUniImageProcessorCallback@@@Z @ 1 NONAME ; CUniImageProcessor::CUniImageProcessor(class MUniImageProcessorCallback *)
	?changePriority@MsgUnifiedEditorView@@AAEXXZ @ 2 NONAME ; void MsgUnifiedEditorView::changePriority(void)
	?populateDraftsContent@MsgUnifiedEditorView@@AAEXABVConvergedMessage@@@Z @ 3 NONAME ; void MsgUnifiedEditorView::populateDraftsContent(class ConvergedMessage const &)
	?openDraftsMessage@MsgUnifiedEditorView@@QAEXAAVConvergedMessageId@@W4MessageType@ConvergedMessage@@@Z @ 4 NONAME ; void MsgUnifiedEditorView::openDraftsMessage(class ConvergedMessageId &, enum ConvergedMessage::MessageType)
	?updateOtherRecipientCount@MsgUnifiedEditorView@@AAEX_N@Z @ 5 NONAME ; void MsgUnifiedEditorView::updateOtherRecipientCount(bool)
	?qt_metacall@MsgUnifiedEditorView@@UAEHW4Call@QMetaObject@@HPAPAX@Z @ 6 NONAME ; int MsgUnifiedEditorView::qt_metacall(enum QMetaObject::Call, int, void * *)
	?sendingOptions@MsgUnifiedEditorView@@AAEXXZ @ 7 NONAME ; void MsgUnifiedEditorView::sendingOptions(void)
	?launchHelp@MsgUnifiedEditorView@@AAEXXZ @ 8 NONAME ; void MsgUnifiedEditorView::launchHelp(void)
	?staticMetaObject@MsgUnifiedEditorView@@2UQMetaObject@@B @ 9 NONAME ; struct QMetaObject const MsgUnifiedEditorView::staticMetaObject
	?resizeEvent@MsgUnifiedEditorView@@MAEXPAVQGraphicsSceneResizeEvent@@@Z @ 10 NONAME ; void MsgUnifiedEditorView::resizeEvent(class QGraphicsSceneResizeEvent *)
	?ScaleImageL@CUniImageProcessor@@QAEXPAVCFbsBitmap@@0H@Z @ 11 NONAME ; void CUniImageProcessor::ScaleImageL(class CFbsBitmap *, class CFbsBitmap *, int)
	?addCcBcc@MsgUnifiedEditorView@@AAEXXZ @ 12 NONAME ; void MsgUnifiedEditorView::addCcBcc(void)
	?ProcessImageL@CUniImageProcessor@@QAEXAAVRFile@@0AAVTSize@@ABVTDesC8@@HH@Z @ 13 NONAME ; void CUniImageProcessor::ProcessImageL(class RFile &, class RFile &, class TSize &, class TDesC8 const &, int, int)
	?audiosFetched@MsgUnifiedEditorView@@AAEXABVQVariant@@@Z @ 14 NONAME ; void MsgUnifiedEditorView::audiosFetched(class QVariant const &)
	?metaObject@MsgUnifiedEditorView@@UBEPBUQMetaObject@@XZ @ 15 NONAME ; struct QMetaObject const * MsgUnifiedEditorView::metaObject(void) const
	?saveContentToDrafts@MsgUnifiedEditorView@@QAE_NXZ @ 16 NONAME ; bool MsgUnifiedEditorView::saveContentToDrafts(void)
	?addSubject@MsgUnifiedEditorView@@AAEXXZ @ 17 NONAME ; void MsgUnifiedEditorView::addSubject(void)
	?imagesFetched@MsgUnifiedEditorView@@AAEXABVQVariant@@@Z @ 18 NONAME ; void MsgUnifiedEditorView::imagesFetched(class QVariant const &)
	?qt_metacast@MsgUnifiedEditorView@@UAEPAXPBD@Z @ 19 NONAME ; void * MsgUnifiedEditorView::qt_metacast(char const *)
	?ScaleImageL@CUniImageProcessor@@QAEXAAVRFile@@AAPAVCFbsBitmap@@1AAVTSize@@H@Z @ 20 NONAME ; void CUniImageProcessor::ScaleImageL(class RFile &, class CFbsBitmap * &, class CFbsBitmap * &, class TSize &, int)
	?addMenu@MsgUnifiedEditorView@@AAEXXZ @ 21 NONAME ; void MsgUnifiedEditorView::addMenu(void)
	??_EMsgUnifiedEditorView@@UAE@I@Z @ 22 NONAME ; MsgUnifiedEditorView::~MsgUnifiedEditorView(unsigned int)
	??1MsgUnifiedEditorView@@UAE@XZ @ 23 NONAME ; MsgUnifiedEditorView::~MsgUnifiedEditorView(void)
	?packMessage@MsgUnifiedEditorView@@AAEXAAVConvergedMessage@@@Z @ 24 NONAME ; void MsgUnifiedEditorView::packMessage(class ConvergedMessage &)
	?trUtf8@MsgUnifiedEditorView@@SA?AVQString@@PBD0@Z @ 25 NONAME ; class QString MsgUnifiedEditorView::trUtf8(char const *, char const *)
	?tr@MsgUnifiedEditorView@@SA?AVQString@@PBD0@Z @ 26 NONAME ; class QString MsgUnifiedEditorView::tr(char const *, char const *)
	?ScaleImageL@CUniImageProcessor@@QAEXPAVCFbsBitmap@@AAVRFile@@ABVTSize@@ABVTDesC8@@H@Z @ 27 NONAME ; void CUniImageProcessor::ScaleImageL(class CFbsBitmap *, class RFile &, class TSize const &, class TDesC8 const &, int)
	?getStaticMetaObject@MsgUnifiedEditorView@@SAABUQMetaObject@@XZ @ 28 NONAME ; struct QMetaObject const & MsgUnifiedEditorView::getStaticMetaObject(void)
	?tr@MsgUnifiedEditorView@@SA?AVQString@@PBD0H@Z @ 29 NONAME ; class QString MsgUnifiedEditorView::tr(char const *, char const *, int)
	?send@MsgUnifiedEditorView@@AAEXXZ @ 30 NONAME ; void MsgUnifiedEditorView::send(void)
	?Reset@CUniImageProcessor@@QAEXXZ @ 31 NONAME ; void CUniImageProcessor::Reset(void)
	?addToolBar@MsgUnifiedEditorView@@AAEXXZ @ 32 NONAME ; void MsgUnifiedEditorView::addToolBar(void)
	?removeAttachmentContainer@MsgUnifiedEditorView@@AAEXXZ @ 33 NONAME ; void MsgUnifiedEditorView::removeAttachmentContainer(void)
	?pluginPath@MsgUnifiedEditorView@@AAE?AVQString@@XZ @ 34 NONAME ; class QString MsgUnifiedEditorView::pluginPath(void)
	?trUtf8@MsgUnifiedEditorView@@SA?AVQString@@PBD0H@Z @ 35 NONAME ; class QString MsgUnifiedEditorView::trUtf8(char const *, char const *, int)
	??0MsgUnifiedEditorView@@QAE@PAVQGraphicsItem@@@Z @ 36 NONAME ; MsgUnifiedEditorView::MsgUnifiedEditorView(class QGraphicsItem *)
	?populateContent@MsgUnifiedEditorView@@QAEXABVConvergedMessage@@H@Z @ 37 NONAME ; void MsgUnifiedEditorView::populateContent(class ConvergedMessage const &, int)
	?showAttachmentPopup@MsgUnifiedEditorView@@AAEXXZ @ 38 NONAME ; void MsgUnifiedEditorView::showAttachmentPopup(void)
	?deleteMessage@MsgUnifiedEditorView@@AAEXXZ @ 39 NONAME ; void MsgUnifiedEditorView::deleteMessage(void)
	?addAttachment@MsgUnifiedEditorView@@AAEXABVQString@@@Z @ 40 NONAME ; void MsgUnifiedEditorView::addAttachment(class QString const &)

